@@ -26,6 +26,9 @@ class Config(object):
   BOOK_LOAD_SNS_TOPIC_ARN = 'arn:aws:sns:us-west-1:791608169866:booking-agent-book-load-test'
   BOOK_LOAD_SNS_SUBJECT = 'book-load'
   BOOK_LOAD_SNS_CLASS_NAME = 'com.cargochief.sdk.bookingagent.sns.BookLoadNotification'
+  IMPORT_MOVEMENTS_SNS_TOPIC_ARN = 'arn:aws:sns:us-west-1:791608169866:mcleod-import-movements-test'
+  IMPORT_MOVEMENTS_SNS_SUBJECT = 'import-movements'
+  IMPORT_MOVEMENTS_SNS_CLASS_NAME = 'com.cargochief.sdk.c4.sns.mcleod.ImportMovementsNotification'
 
 class LocalConfig(Config):
   """Configurations for running and debugging locally, with a separate local database."""
@@ -44,6 +47,7 @@ class ProductionConfig(Config):
   """Configurations for running in dev mode, with a remote database."""
   PARSED_CARRIER_SNS_TOPIC_ARN = 'arn:aws:sns:us-west-1:791608169866:mcleod-parsed-carrier-prod'  
   BOOK_LOAD_SNS_TOPIC_ARN = 'arn:aws:sns:us-west-1:791608169866:booking-agent-book-load-prod'
+  IMPORT_MOVEMENTS_SNS_TOPIC_ARN = 'arn:aws:sns:us-west-1:791608169866:mcleod-import-movements-prod'
 
 config_options = {
     'local': LocalConfig,
